## Download 'Namasha.com' videos with python


**Installation**
```python
pip install pynamasha
```

**usage**
```python
from pynamasha import Download

video = Download(url='https://www.namasha.com/v/TFVnmajX', quality='240')
video.download()
```